import { CommonModule } from '@angular/common';
import { InjectionToken, NgModule, Injectable, Inject, ɵɵdefineInjectable, ɵɵinject } from '@angular/core';
import Code from '@editorjs/code';
import Embed from '@editorjs/embed';
import Header from '@editorjs/header';
import Image from '@editorjs/image';
import InlineCode from '@editorjs/inline-code';
import Link from '@editorjs/link';
import List from '@editorjs/list';
import Marker from '@editorjs/paragraph';
import Quote from '@editorjs/quote';
import SimpleImage from '@editorjs/simple-image';
import Warning from '@editorjs/warning';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const PluginTypes = {
    /**
     * A EditorJS block plugin
     */
    Block: 'block',
    /**
     * A EditorJS inline plugin
     */
    Inline: 'inline',
};
/**
 * The Injection token for initial plugins as defined in the ngx-editorjs module
 * @type {?}
 */
const EDITOR_JS_TOOL_INJECTOR = new InjectionToken('EDITOR_JS_TOOL_INJECTOR');
/**
 * Injection token for a plugin config
 * @type {?}
 */
const PLUGIN_CONFIG = new InjectionToken('PLUGIN_CONFIG');
/**
 * Injection token for the plugin config map
 * @type {?}
 */
const PluginClasses = new InjectionToken('PluginClasses');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0 = Code, ɵ1 = {
    key: 'code',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Code'
};
/**
 * A module that provides the default EditorJS `<code>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/code) for API details
 */
class PluginCodeModule {
}
PluginCodeModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: ɵ0,
                        multi: true
                    },
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ1,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$1 = Embed, ɵ1$1 = {
    key: 'embed',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Embed Block',
    inlineToolbar: true
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
class PluginEmbedModule {
}
PluginEmbedModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: ɵ0$1,
                        multi: true
                    },
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ1$1,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
//TODO: Remove once Header plugin has been fixed
class FixedHeader extends Header {
    /**
     * @param {?} config
     */
    constructor(config) {
        super(config);
    }
    /**
     * Fixed version of the function to normalize input data
     * @param {?=} data The data for the header
     * @return {?} The new header data
     */
    normalizeData(data = {}) {
        /** @type {?} */
        const newData = {};
        newData.text = data.text || '';
        newData.level = parseInt(data.level, 10) || ((/** @type {?} */ (this))).defaultLevel.number;
        return newData;
    }
}
const ɵ0$2 = {
    key: 'header',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Header'
};
/**
 * A module that provides the default EditorJS header block tool.
 * See [the GitHub repo](https://github.com/editor-js/header) for API details
 */
class PluginHeaderModule {
}
PluginHeaderModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: FixedHeader,
                        multi: true
                    },
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ0$2,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$3 = Image, ɵ1$2 = {
    key: 'image',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Image'
};
/**
 * A module that provides the default EditorJS `<img>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/image) for API details
 */
class PluginImageModule {
}
PluginImageModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: ɵ0$3,
                        multi: true
                    },
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ1$2,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$4 = InlineCode, ɵ1$3 = {
    key: 'inline-code',
    type: PluginTypes.Inline,
    pluginName: 'EditorJS Inline Code',
    shortcut: 'CTRL+SHIFT+C'
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
class PluginInlineCodeModule {
}
PluginInlineCodeModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: ɵ0$4,
                        multi: true
                    },
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ1$3,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$5 = Link, ɵ1$4 = {
    key: 'link',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Link'
};
/**
 * A module that provides the default EditorJS `<img>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/image) for API details
 */
class PluginLinkModule {
}
PluginLinkModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: ɵ0$5,
                        multi: true
                    },
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ1$4,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$6 = List, ɵ1$5 = {
    key: 'list',
    type: PluginTypes.Block,
    pluginName: 'EditorJS List'
};
/**
 * A module that provides the default EditorJS `<img>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/image) for API details
 */
class PluginListModule {
}
PluginListModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: ɵ0$6,
                        multi: true
                    },
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ1$5,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$7 = Marker, ɵ1$6 = {
    key: 'paragraph',
    type: PluginTypes.Inline,
    pluginName: 'EditorJS Marker',
    shortcut: 'CTRL+SHIFT+M'
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
class PluginMarkerModule {
}
PluginMarkerModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: ɵ0$7,
                        multi: true
                    },
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ1$6,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$8 = Marker, ɵ1$7 = {
    key: 'paragraph',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Paragraph'
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
class PluginParagraphModule {
}
PluginParagraphModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: ɵ0$8,
                        multi: true
                    },
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ1$7,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$9 = Quote, ɵ1$8 = {
    key: 'quote',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Quote Tool',
    inlineToolbar: true
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
class PluginQuoteModule {
}
PluginQuoteModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: ɵ0$9,
                        multi: true
                    },
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ1$8,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$a = SimpleImage, ɵ1$9 = {
    key: 'simpleimage',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Simple Image'
};
/**
 * A module that provides the default EditorJS `<img>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/image) for API details
 */
class PluginSimpleImageModule {
}
PluginSimpleImageModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: ɵ0$a,
                        multi: true
                    },
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ1$9,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$b = Warning, ɵ1$a = {
    key: 'warning',
    type: PluginTypes.Block,
    pluginName: 'EditorJS Warning Block',
    inlineToolbar: true
};
/**
 * A module that provides the default EditorJS `<p>` block tool.
 * See [the GitHub repo](https://github.com/editor-js/paragraph) for API details
 */
class PluginWarningModule {
}
PluginWarningModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: ɵ0$b,
                        multi: true
                    },
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ1$a,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Factory function to create the plugin config map for the plugin service
 * @param {?} pluginConfigs The array of plugin configuration objects passed to this factory
 * @param {?} plugins The array of `EditorJS` plugins that are passed to this factory
 * @return {?}
 */
function createPluginConfig(pluginConfigs, plugins) {
    return pluginConfigs.reduce((/**
     * @param {?} pluginConfig
     * @param {?} config
     * @param {?} index
     * @return {?}
     */
    (pluginConfig, config, index) => typeof config === 'undefined'
        ? pluginConfig
        : Object.assign({}, pluginConfig, { [config.key]: Object.assign({}, config, { plugin: plugins[index] }) })), {});
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The `NgxEditorJSPluginService` is provided as a root service for handling {\@link https://github.com/editor-js | EditorJS plugins}.
 *
 * Plugins are provided by using {\@link https://angular.io/api/core/NgModule | NgModule} to inject the plugin with a
 * {\@link ../interfaces/PluginConfig.html | PluginConfig} using providers.
 */
class NgxEditorJSPluginService {
    /**
     * @param {?} pluginConfigMap The plugin configuration map injected into the application
     */
    constructor(pluginConfigMap) {
        this.pluginConfigMap = pluginConfigMap;
    }
    /**
     * Get a map of all plugin configurations
     * @return {?} The map of plugins injected into this plugin
     */
    getPlugins() {
        return this.pluginConfigMap;
    }
    /**
     * Get a plugin configuration via it's key
     * @param {?} key The key of the plugin to get
     * @return {?} The plugin configuration for the passed key
     */
    getPlugin(key) {
        return this.pluginConfigMap[key];
    }
    /**
     * Get a list of plugins, filtering with an exclude list of plugins
     * @param {?=} excludeList
     * @return {?}
     */
    getPluginsWithExclude(excludeList = []) {
        return Object.entries(this.pluginConfigMap)
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ([key]) => {
            return !excludeList.includes(key);
        }))
            .reduce((/**
         * @param {?} pluginMap
         * @param {?} __1
         * @return {?}
         */
        (pluginMap, [key, plugin]) => {
            return Object.assign({}, pluginMap, { [key]: plugin });
        }), {});
    }
    /**
     * Get a list of plugins, filtering with an include list of plugins
     * @param {?=} includeList
     * @return {?}
     */
    getPluginsWithInclude(includeList = []) {
        return Object.entries(this.pluginConfigMap)
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ([key]) => {
            return includeList.includes(key);
        }))
            .reduce((/**
         * @param {?} pluginMap
         * @param {?} __1
         * @return {?}
         */
        (pluginMap, [key, plugin]) => {
            return Object.assign({}, pluginMap, { [key]: plugin });
        }), {});
    }
    /**
     * Returns a map of {\@link https://editorjs.io/api | EditorJS} tools to be initialized by the editor
     * @param {?=} excludeTools Optional array of tools to exclude, if not passed all tools
     * @return {?}
     */
    getTools(excludeTools = []) {
        return Object.entries(this.getPluginsWithExclude(excludeTools)).reduce((/**
         * @param {?} finalTools
         * @param {?} __1
         * @return {?}
         */
        (finalTools, [key, plugin]) => {
            /** @type {?} */
            const tool = {
                class: plugin.plugin
            };
            if (plugin.shortcut)
                tool.shortcut = plugin.shortcut;
            if (plugin.type === 'inline' || plugin.inlineToolbar)
                tool.inlineToolbar = true;
            if (plugin.config)
                tool.config = plugin.config;
            return Object.assign({}, finalTools, { [key]: tool });
        }), {});
    }
}
NgxEditorJSPluginService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
NgxEditorJSPluginService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [PluginClasses,] }] }
];
/** @nocollapse */ NgxEditorJSPluginService.ngInjectableDef = ɵɵdefineInjectable({ factory: function NgxEditorJSPluginService_Factory() { return new NgxEditorJSPluginService(ɵɵinject(PluginClasses)); }, token: NgxEditorJSPluginService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$c = undefined, ɵ1$b = undefined, ɵ2 = createPluginConfig;
class NgxEditorJSPluginServiceModule {
}
NgxEditorJSPluginServiceModule.decorators = [
    { type: NgModule, args: [{
                providers: [
                    {
                        provide: PLUGIN_CONFIG,
                        useValue: ɵ0$c,
                        multi: true
                    },
                    {
                        provide: EDITOR_JS_TOOL_INJECTOR,
                        useValue: ɵ1$b,
                        multi: true
                    },
                    {
                        provide: PluginClasses,
                        useFactory: ɵ2,
                        deps: [PLUGIN_CONFIG, EDITOR_JS_TOOL_INJECTOR]
                    },
                    NgxEditorJSPluginService
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The `NgxEditorjsPluginsModule` provides several additional modules
 * that provide a way to easily plug in block and inline tools for EditorJS.
 *
 * Importing `NgxEditorjsPluginsModule` will include all modules, while it
 * is also possible to import each individual module as required.
 */
class NgxEditorjsPluginsModule {
}
NgxEditorjsPluginsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    NgxEditorJSPluginServiceModule,
                    PluginCodeModule,
                    PluginHeaderModule,
                    PluginImageModule,
                    PluginLinkModule,
                    PluginListModule,
                    PluginMarkerModule,
                    PluginParagraphModule,
                    PluginSimpleImageModule,
                    PluginInlineCodeModule,
                    PluginWarningModule,
                    PluginQuoteModule,
                    PluginEmbedModule
                ],
                exports: [
                    NgxEditorJSPluginServiceModule,
                    PluginCodeModule,
                    PluginHeaderModule,
                    PluginImageModule,
                    PluginLinkModule,
                    PluginListModule,
                    PluginMarkerModule,
                    PluginParagraphModule,
                    PluginSimpleImageModule,
                    PluginInlineCodeModule,
                    PluginWarningModule,
                    PluginQuoteModule,
                    PluginEmbedModule
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { EDITOR_JS_TOOL_INJECTOR, NgxEditorJSPluginService, NgxEditorJSPluginServiceModule, NgxEditorjsPluginsModule, PLUGIN_CONFIG, PluginClasses, PluginCodeModule, PluginEmbedModule, PluginHeaderModule, PluginImageModule, PluginInlineCodeModule, PluginLinkModule, PluginListModule, PluginMarkerModule, PluginParagraphModule, PluginQuoteModule, PluginSimpleImageModule, PluginTypes, PluginWarningModule, createPluginConfig, FixedHeader as ɵa };
//# sourceMappingURL=tinynodes-ngx-editorjs-plugins.js.map
