import { PluginConfig, PluginConfigMap, ToolSettingsMap } from '../types/plugins';
/**
 * The `NgxEditorJSPluginService` is provided as a root service for handling {@link https://github.com/editor-js | EditorJS plugins}.
 *
 * Plugins are provided by using {@link https://angular.io/api/core/NgModule | NgModule} to inject the plugin with a
 * {@link ../interfaces/PluginConfig.html | PluginConfig} using providers.
 */
export declare class NgxEditorJSPluginService {
    private readonly pluginConfigMap;
    /**
     * @param pluginConfigMap The plugin configuration map injected into the application
     */
    constructor(pluginConfigMap: PluginConfigMap);
    /**
     * Get a map of all plugin configurations
     * @returns The map of plugins injected into this plugin
     */
    getPlugins(): PluginConfigMap;
    /**
     * Get a plugin configuration via it's key
     * @param key The key of the plugin to get
     * @returns The plugin configuration for the passed key
     */
    getPlugin(key: string): PluginConfig;
    /**
     * Get a list of plugins, filtering with an exclude list of plugins
     * @param excludeList
     */
    getPluginsWithExclude(excludeList?: string[]): PluginConfigMap;
    /**
     * Get a list of plugins, filtering with an include list of plugins
     * @param includeList
     */
    getPluginsWithInclude(includeList?: string[]): PluginConfigMap;
    /**
     * Returns a map of {@link https://editorjs.io/api | EditorJS} tools to be initialized by the editor
     * @param excludeTools Optional array of tools to exclude, if not passed all tools
     */
    getTools(excludeTools?: string[]): ToolSettingsMap;
}
